@@ -37,7 +37,6 @@ public class ImportCommand : FSpot.GladeDialog {
 
 	internal class VfsSource : ImportSource {
 		public string uri;
-		public bool SuggestCopy = false;
 
 		public VfsSource (string uri)
 		{ 
@@ -67,17 +66,22 @@ public class ImportCommand : FSpot.GladeDialog {
 		{
 			this.Volume = vol;
 			this.Name = vol.DisplayName.Replace ("_", "__");
-			mount_point = new Uri (vol.ActivationUri).LocalPath;
-			uri = mount_point;
-			SuggestCopy = true;
 
+			try {
+				mount_point = new Uri (vol.ActivationUri).LocalPath;
+			} catch (System.Exception e) {
+				System.Console.WriteLine (e);
+			}
+
+			uri = mount_point;
+			
                         if (this.Icon == null)
 				this.Icon = PixbufUtils.LoadThemeIcon (vol.Icon, 32);
 			
 			if (this.IsiPodPhoto)
 				this.Icon = PixbufUtils.LoadThemeIcon ("gnome-dev-ipod", 32);
 
-                        if (this.Icon == null)			if (this.Icon == null && this.IsCamera)
+			if (this.Icon == null && this.IsCamera)
 				this.Icon = PixbufUtils.LoadThemeIcon ("gnome-dev-media-cf", 32);
 
 			try {
@@ -362,6 +366,7 @@ public class ImportCommand : FSpot.GladeDialog {
 	[Glade.Widget] Gtk.ScrolledWindow photo_scrolled;
 	[Glade.Widget] Gtk.CheckButton attach_check;
 	[Glade.Widget] Gtk.CheckButton recurse_check;
+	[Glade.Widget] Gtk.CheckButton copy_check;
 	[Glade.Widget] Gtk.Button ok_button;
 	[Glade.Widget] Gtk.Image tag_image;
 	[Glade.Widget] Gtk.Label tag_label;
@@ -386,10 +391,13 @@ public class ImportCommand : FSpot.GladeDialog {
 	IconView tray;
 	ImportBackend importer;
 
+	string loading_string;
+
 	public ImportCommand (Gtk.Window mw)
 	{
 		main_window = mw;
 		step = new FSpot.Delay (10, new GLib.IdleHandler (Step));
+		loading_string = Mono.Posix.Catalog.GetString ("Loading {0} of {1}");
 	}
 
 	private void HandleDialogResponse (object obj, ResponseArgs args)
@@ -406,7 +414,7 @@ public class ImportCommand : FSpot.GladeDialog {
 		if (progress_bar == null)
 			return;
 
-		progress_bar.Text = String.Format ("Importing {0} of {1}", count, total);
+		progress_bar.Text = String.Format (loading_string, count, total);
 		progress_bar.Fraction = (double) count / System.Math.Max (total, 1);
 	}
 
@@ -444,7 +452,9 @@ public class ImportCommand : FSpot.GladeDialog {
 			collection.Add (photo);
 		
 			//grid.AddThumbnail (thumbnail);
-			UpdateProgressBar (count, total);
+			if (count < total)
+				UpdateProgressBar (count + 1, total);
+
 			thumbnail.Dispose ();
 		}
 
@@ -472,9 +482,11 @@ public class ImportCommand : FSpot.GladeDialog {
 
 		this.importer = imp;
 		AllowFinish = false;
-
+		
 		total = importer.Prepare ();
-		UpdateProgressBar (0, total);
+
+		if (total > 0)
+			UpdateProgressBar (1, total);
 		
 		collection.Clear ();
 		collection.Capacity = total;
@@ -503,6 +515,8 @@ public class ImportCommand : FSpot.GladeDialog {
 		if (cancelled)
 			return 0;
 		else {
+			if (progress_bar != null)
+				progress_bar.Text = Mono.Posix.Catalog.GetString ("Done Loading");
 			AllowFinish = true;
 			return total;
 		}
@@ -551,7 +565,7 @@ public class ImportCommand : FSpot.GladeDialog {
 		file_selector.Destroy ();
 		return path;
 	}
-	
+
 	public void SetImportPath (string path)
 	{
 		import_path = path;
@@ -571,7 +585,7 @@ public class ImportCommand : FSpot.GladeDialog {
 			return;
 		
 		this.Cancel ();
-		this.copy = false;
+		this.copy = copy_check.Active;
 		AllowFinish = false;
 
 		Gtk.OptionMenu option = (Gtk.OptionMenu) sender;
@@ -594,11 +608,6 @@ public class ImportCommand : FSpot.GladeDialog {
 			}
 		} else if (item.Source is VfsSource) {
 			VfsSource vfs = item.Source as VfsSource;
-
-			// If the paths are the Same no need to reload.
-			if (vfs is VolumeSource)
-				copy = true;
-			
 			SetImportPath (vfs.uri);
 		} else if (item.Source is CameraSource) {
 			CameraSource csource = item.Source as CameraSource;
@@ -643,6 +652,7 @@ public class ImportCommand : FSpot.GladeDialog {
 	        AllowFinish = false;
 		
 		recurse_check.Toggled += HandleRecurseToggled;
+		copy_check.Toggled += HandleRecurseToggled;
 
 		tag_option_menu.Menu = tagmenu;
 		SourceMenu menu = new SourceMenu ();
@@ -742,10 +752,11 @@ public class ImportCommand : FSpot.GladeDialog {
 		if (collection == null || collection.Count == 0)
 			return;
 		
-		// FIXME this should be a transaction or a multiple remove.
-		for (int i = 0; i < collection.Count; i++) {
-			store.Remove ((Photo)(collection [i]));
-		}
+		Photo [] photos = new Photo [collection.Count];
+		for (int i = 0; i < collection.Count; i++)
+			photos [i] = (Photo) collection [i];
+
+		store.Remove (photos);
 	}
 
 	public int Start ()
@@ -771,10 +782,20 @@ public class ImportCommand : FSpot.GladeDialog {
 		return ImportFromPaths (store, paths, null);
 	}
 
+    public int ImportFromPaths (PhotoStore store, string [] paths, bool copy)
+    {
+        return ImportFromPaths (store, paths, null, copy);
+    }
+
 	public int ImportFromPaths (PhotoStore store, string [] paths, Tag [] tags)
+	{
+		return ImportFromPaths (store, paths, tags, false);
+	}
+	
+	public int ImportFromPaths (PhotoStore store, string [] paths, Tag [] tags, bool copy)
 	{
 		collection = new FSpot.PhotoList (new Photo [0]);
-		return DoImport (new FileImportBackend (store, paths, false, true, tags));
+		return DoImport (new FileImportBackend (store, paths, copy, true, tags));
 	}
 	
 #if TEST_IMPORT_COMMAND
